Django Grappelli
================

**A jazzy skin for the Django admin interface**.

Grappelli is a grid-based alternative/extension to the `Django <http://www.djangoproject.com>`_ administration interface.

Code
----

https://github.com/sehmaschine/django-grappelli

Documentation
-------------

http://readthedocs.org/docs/django-grappelli/

Releases
--------

**Grappelli is always developed against the latest stable Django release and is NOT tested with Djangos trunk.**

* |grappelli| 2.5.3 (April 13th, 2014): Compatible with Django 1.6
* |grappelli| 2.4.10 (April 13th, 2014): Compatible with Django 1.4/1.5

Current development branches:

* |grappelli| 2.5.4 (Development version for Django 1.6, not yet released, see branch Stable/2.5.x)
* |grappelli| 2.4.11 (Development version for Django 1.4/1.5, not yet released, see branch Stable/2.4.x)

Older versions are availabe at GitHub, but are not supported anymore.
